// automatically generated by admSerialization.py do not edit
#include "string"
#pragma once
typedef struct {
uint32_t version;
uint32_t MultiThreaded;
bool _4MV;
bool _QPEL;
bool _TRELLIS_QUANT;
uint32_t qmin;
uint32_t qmax;
uint32_t max_qdiff;
uint32_t max_b_frames;
uint32_t mpeg_quant;
uint32_t is_luma_elim_threshold;
uint32_t luma_elim_threshold;
uint32_t is_chroma_elim_threshold;
uint32_t chroma_elim_threshold;
float lumi_masking;
int32_t is_lumi_masking;
float dark_masking;
int32_t is_dark_masking;
float qcompress;
float qblur;
uint32_t minBitrate;
uint32_t maxBitrate;
uint32_t user_matrix;
uint32_t gop_size;
bool interlaced;
bool bff;
bool widescreen;
uint32_t mb_eval;
uint32_t vratetol;
bool is_temporal_cplx_masking;
float temporal_cplx_masking;
bool is_spatial_cplx_masking;
float spatial_cplx_masking;
bool _NORMALIZE_AQP;
bool use_xvid_ratecontrol;
uint32_t bufferSize;
bool override_ratecontrol;
uint32_t dummy;
}FFcodecContext;
