/***************************************************************************
            \file audiofilter_internal.h
            \brief Creates destroy audio filters
              (c) 2006 Mean , fixounet@free.fr
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef  audiofilter_internal_h
#define  audiofilter_internal_h
#include "audiofilter.h"

#include <vector>

typedef std::vector <AUDMAudioFilter *>VectorOfAudioFilter;


#endif